@@ -1,16 +1,17 @@
-from __future__ import absolute_import, division, print_function
-
 import io
 import itertools
 import math
 import uuid
 import warnings
 from collections import defaultdict
+from collections.abc import Iterable, Iterator
 from distutils.version import LooseVersion
 from functools import wraps, partial
 from operator import getitem
 from random import Random
+from urllib.request import urlopen
 
+import toolz
 from toolz import (
     merge,
     take,
@@ -27,8 +28,6 @@ from toolz import (
     accumulate,
     peek,
 )
-from toolz.compatibility import iteritems, zip
-import toolz
 
 _implement_accumulate = LooseVersion(toolz.__version__) > "0.7.4"
 try:
@@ -66,7 +65,6 @@ from .. import config
 from .avro import to_avro
 from ..base import tokenize, dont_optimize, DaskMethodsMixin
 from ..bytes import open_files
-from ..compatibility import apply, urlopen, Iterable, Iterator
 from ..context import globalmethod
 from ..core import quote, istask, get_dependencies, reverse_dict, flatten
 from ..delayed import Delayed, unpack_collections
@@ -74,6 +72,7 @@ from ..highlevelgraph import HighLevelGraph
 from ..multiprocessing import get as mpget
 from ..optimization import fuse, cull, inline
 from ..utils import (
+    apply,
     system_encoding,
     takes_multiple_arguments,
     funcname,
@@ -1915,7 +1914,7 @@ def merge_frequencies(seqs):
     out = defaultdict(int)
     out.update(first)
     for d in rest:
-        for k, v in iteritems(d):
+        for k, v in d.items():
             out[k] += v
     return out
 
