@@ -1,5 +1,6 @@
 from .methods import concat_dispatch
 from .core import get_parallel_type, meta_nonempty, make_meta
+from .utils import hash_object_dispatch
 
 
 ######################################
@@ -8,6 +9,7 @@ from .core import get_parallel_type, meta_nonempty, make_meta
 
 
 @concat_dispatch.register_lazy("cudf")
+@hash_object_dispatch.register_lazy("cudf")
 @get_parallel_type.register_lazy("cudf")
 @meta_nonempty.register_lazy("cudf")
 @make_meta.register_lazy("cudf")
