@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 from datetime import datetime
 from collections import defaultdict
 
@@ -13,7 +11,6 @@ from .utils import is_index_like
 from . import methods
 from ..base import tokenize
 from ..highlevelgraph import HighLevelGraph
-from .. import compatibility
 
 
 class _IndexerBase(object):
@@ -345,18 +342,18 @@ def _maybe_partial_time_string(index, indexer, kind):
         return indexer
 
     if isinstance(indexer, slice):
-        if isinstance(indexer.start, compatibility.string_types):
+        if isinstance(indexer.start, str):
             start = index._maybe_cast_slice_bound(indexer.start, "left", kind)
         else:
             start = indexer.start
 
-        if isinstance(indexer.stop, compatibility.string_types):
+        if isinstance(indexer.stop, str):
             stop = index._maybe_cast_slice_bound(indexer.stop, "right", kind)
         else:
             stop = indexer.stop
         return slice(start, stop)
 
-    elif isinstance(indexer, compatibility.string_types):
+    elif isinstance(indexer, str):
         start = index._maybe_cast_slice_bound(indexer, "left", "loc")
         stop = index._maybe_cast_slice_bound(indexer, "right", "loc")
         return slice(min(start, stop), max(start, stop))
