@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 from distutils.version import LooseVersion
 
 import toolz
@@ -10,7 +8,6 @@ from fsspec.utils import stringify_path
 
 from ...core import DataFrame, new_dd_object
 from ....base import tokenize
-from ....compatibility import PY3, string_types
 from ....utils import import_required, natural_sort_key
 
 
@@ -381,7 +378,7 @@ def to_parquet(
             compression = None
 
     partition_on = partition_on or []
-    if isinstance(partition_on, string_types):
+    if isinstance(partition_on, str):
         partition_on = [partition_on]
 
     if set(partition_on) - set(df.columns):
@@ -567,6 +564,9 @@ def sorted_columns(statistics):
         success = True
         for stats in statistics[1:]:
             c = stats["columns"][i]
+            if c["min"] is None:
+                success = False
+                break
             if c["min"] >= max:
                 divisions.append(c["min"])
                 max = c["max"]
@@ -632,5 +632,4 @@ def apply_filters(parts, statistics, filters):
     return parts, statistics
 
 
-if PY3:
-    DataFrame.to_parquet.__doc__ = to_parquet.__doc__
+DataFrame.to_parquet.__doc__ = to_parquet.__doc__
