@@ -1,10 +1,8 @@
-from __future__ import print_function, division, absolute_import
-
 from io import BytesIO
 import os
 import gzip
-import sys
 from time import sleep
+from unittest import mock
 
 import pytest
 
@@ -18,6 +16,7 @@ import pandas.util.testing as tm
 import dask
 import dask.dataframe as dd
 from dask.base import compute_as_if_collection
+from dask.compatibility import PY_VERSION
 from dask.dataframe.io.csv import (
     text_blocks_to_pandas,
     pandas_read_text,
@@ -703,7 +702,7 @@ def test_read_csv_sensitive_to_enforce():
 
 @pytest.mark.parametrize("fmt,blocksize", fmt_bs)
 def test_read_csv_compression(fmt, blocksize):
-    if fmt == "zip" and sys.version_info.minor == 5:
+    if fmt == "zip" and PY_VERSION < "3.6":
         pytest.skip("zipfile is read-only on py35")
     if fmt not in compress:
         pytest.skip("compress function not provided for %s" % fmt)
@@ -773,10 +772,6 @@ def test_auto_blocksize_max64mb():
 
 def test_auto_blocksize_csv(monkeypatch):
     psutil = pytest.importorskip("psutil")
-    try:
-        from unittest import mock
-    except ImportError:
-        mock = pytest.importorskip("mock")
     total_memory = psutil.virtual_memory().total
     cpu_count = psutil.cpu_count()
     mock_read_bytes = mock.Mock(wraps=read_bytes)
