@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import os
 import pytest
 from operator import add, mul
@@ -30,7 +28,6 @@ from dask.base import (
 from dask.delayed import Delayed
 from dask.utils import tmpdir, tmpfile, ignoring
 from dask.utils_test import inc, dec
-from dask.compatibility import long, unicode, PY2
 from dask.diagnostics import Profiler
 
 
@@ -143,12 +140,6 @@ def test_tokenize_numpy_array_on_object_dtype():
     assert tokenize(
         np.array([(1, "a"), (1, None), (1, "aaa")], dtype=object)
     ) == tokenize(np.array([(1, "a"), (1, None), (1, "aaa")], dtype=object))
-    if PY2:
-        assert tokenize(
-            np.array([unicode("Rebeca Alón", encoding="utf-8")], dtype=object)
-        ) == tokenize(
-            np.array([unicode("Rebeca Alón", encoding="utf-8")], dtype=object)
-        )
 
 
 @pytest.mark.skipif("not np")
@@ -234,7 +225,7 @@ def test_tokenize_partial_func_args_kwargs_consistent():
 
 
 def test_normalize_base():
-    for i in [1, long(1), 1.1, "1", slice(1, 2, 3)]:
+    for i in [1, 1.1, "1", slice(1, 2, 3)]:
         assert normalize_token(i) is i
 
 
@@ -341,15 +332,14 @@ def test_tokenize_set():
 
 
 def test_tokenize_ordered_dict():
-    with ignoring(ImportError):
-        from collections import OrderedDict
+    from collections import OrderedDict
 
-        a = OrderedDict([("a", 1), ("b", 2)])
-        b = OrderedDict([("a", 1), ("b", 2)])
-        c = OrderedDict([("b", 2), ("a", 1)])
+    a = OrderedDict([("a", 1), ("b", 2)])
+    b = OrderedDict([("a", 1), ("b", 2)])
+    c = OrderedDict([("b", 2), ("a", 1)])
 
-        assert tokenize(a) == tokenize(b)
-        assert tokenize(a) != tokenize(c)
+    assert tokenize(a) == tokenize(b)
+    assert tokenize(a) != tokenize(c)
 
 
 @pytest.mark.skipif("not np")
